%define name gcc-plugin-melt
%define srcname melt-%{meltversion}-plugin-for-gcc-%{meltbranch}
%define meltversion 0.9
%define meltbranch 4.6
%define version %{meltversion}

%define gccplugindir %(gcc -print-file-name=plugin)
%define vimdir %{_datadir}/vim

Name:		%{name}
Version:	%{version}
Epoch:		2
Release:	18
License:	GPLv3
Summary:	Middle End Lisp Translator GCC plugin
Group:		Development/C
URL:		http://gcc-melt.org
Source0:	http://gcc-melt.org/%{srcname}.tgz
# From https://gitorious.org/melt-vim-syntax/melt-vim-syntax/archive-tarball/master
Source1:	melt-vim-syntax.tar.gz
Source2:	ftdetect-melt.vim
Patch0:		melt-stage0-static.patch
Patch1:		gcc-plugin-melt-parallel-build.patch
Requires:	gcc
Requires:	gcc-plugin-devel
Suggests:	%{name}-doc
Suggests:	%{name}-vim
BuildConflicts:	gccmelt
BuildRequires:	gcc-plugin-devel
BuildRequires:	gmp-devel
BuildRequires:	ppl-devel
BuildRequires:	ppl_c-devel
BuildRequires:	mpfr-devel
BuildRequires:	libmpc-devel
BuildRequires:	texinfo
BuildRequires:	texi2html
BuildRequires:	autogen
Provides:	gccmelt

%description
GCC MELT is a GCC plugin providing a lispy domain specific
language to easily code GCC extensions in.

GCC MELT should interest any important software project
(coded in C, C++, Ada, Fortran, ...), compiled with GCC,
since it facilitates the development of customized GCC
extensions for:

* specific warnings or typechecks
* specific optimizations
* coding rules validation
* source code navigation or processing, in particular aspect
  oriented programming, retro-engineering or refactoring tasks
* Any processing taking advantage of powerful GCC internal
  representations of your source code.

%post
  %_install_info meltplugin.info
  %_install_info meltpluginapi.info

%preun
  %_remove_install_info meltplugin.info
  %_remove_install_info meltpluginapi.info

%files
%{_bindir}/pygmentize-melt
%{gccplugindir}/include/*
%{gccplugindir}/melt-sources/*
%{gccplugindir}/melt-modules/*
%{gccplugindir}/melt-module.mk
%{gccplugindir}/melt.so
%{_infodir}/meltplugin*

%package doc
Summary:	GCC MELT Plugin Documentation
BuildArch:	noarch

%description doc
This package provides the GCC MELT documentation.

%files doc
%doc %{_docdir}/gcc-plugin-melt-doc

%package vim
Summary:	VIM plugin to handle GCC MELT files
BuildArch:	noarch

%description vim
This package provides the VIM plugin for syntax and file
type handling of MELT sources.

%files vim
%{vimdir}/ftdetect/
%{vimdir}/ftplugin/
%{vimdir}/syntax/

%prep
%setup -q -n %{srcname} -a 1

# Required workaround suggested by basile to build on x86
#patch0 -p0 -b .stage0

# Removing of .NOTPARALLEL in MELT-Plugin-Makefile
# Must be one WITH usage of make -j (or %make)
#patch1 -p0 -b .notparallel

# Avoid consuming too much memory
#sed -ri 								\
#	-e 's/MELTGCC_OPTIMFLAGS= -O2/MELTGCC_OPTIMFLAGS= -O0/g'	\
#	Makefile

%build
export LC_ALL=C
%make all

%install
export LC_ALL=C
%make DESTDIR=%{buildroot}/ install

%{__install} -m755 -d %{buildroot}%{_bindir}
%{__install} -m755 -d %{buildroot}%{vimdir}
%{__install} -m755 -d %{buildroot}%{_infodir}
%{__install} -m755 -d %{buildroot}%{_docdir}/%{name}-doc/html/

%{__install} -m644 *.info %{buildroot}%{_infodir}
%{__install} -m644 *.html %{buildroot}%{_docdir}/%{name}-doc/html/

%{__install} -m644 -D %{SOURCE2} %{buildroot}%{vimdir}/ftdetect/melt.vim
%{__install} -m644 -D melt-vim-syntax-melt-vim-syntax/ftplugin/melt.vim %{buildroot}%{vimdir}/ftplugin/melt.vim
%{__install} -m644 -D melt-vim-syntax-melt-vim-syntax/syntax/melt.vim %{buildroot}%{vimdir}/syntax/melt.vim

%{__install} -m755 pygmentize-melt %{buildroot}%{_bindir}/

%clean
rm -fr %{buildroot}


%changelog
* Tue Sep 27 2011 Alexandre Lissy <alissy@mandriva.com> 2:0.9-18
+ Revision: 701486
- Push Epoch because of 0.9rc ...
- Providing 0.9 final release in 2011
- Backporting MELT 0.9rc2 for 2011
- Backporting melt 0.9rc0 to 2011
- Backport gcc melt plugin 0.8.99 to 2011

* Fri Jul 01 2011 Alexandre Lissy <alissy@mandriva.com> 4.6.1+0.7-6
+ Revision: 688500
- Bump release
- Adding gccmelt provides

* Wed Jun 29 2011 Alexandre Lissy <alissy@mandriva.com> 4.6.1+0.7-5
+ Revision: 688296
- Fix inconsistency between docdir
- Fix inconsistent path for gcc-plugin-melt-doc

* Wed Jun 29 2011 Alexandre Lissy <alissy@mandriva.com> 4.6.1+0.7-4
+ Revision: 688235
- Introducing documentation package for GCC MELT

* Wed Jun 29 2011 Alexandre Lissy <alissy@mandriva.com> 4.6.1+0.7-3
+ Revision: 688210
- Remove unneeded dependency against gcc-plugin-devel
  Release bump

* Tue Jun 28 2011 Alexandre Lissy <alissy@mandriva.com> 4.6.1+0.7-2
+ Revision: 687647
- gcc-plugin-devel release bump
- gcc-plugin-devel release bump

* Mon Jun 27 2011 Alexandre Lissy <alissy@mandriva.com> 4.6.1+0.7-1
+ Revision: 687596
- Fix gcc plugin directory
- Fix missing /usr/bin creation in buildroot
- Fix pygmentize-melt installation
  Fix file globbing in gccdir
- Fix documentation directory creation
  Set building/installing process quiet
- Introducing separate gcc-plugin-melt package
- Created package structure for gcc-plugin-melt.

